bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.get_mask
=================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.get_mask